@@ -395,7 +395,7 @@ class ComponentTimeRangeMatcher(object):
         vs = {}
         for name, value in indexes.items():
             if name and name[2:] in self.all_props:
-                if value:
+                if value and value[0]:
                     if not isinstance(value[0], vDDDTypes):
                         vs[name[2:]] = vDDDTypes(vDatetime.from_ical(value[0]))
                     else:
@@ -691,6 +691,8 @@ class ParameterFilter(object):
 class CalendarFilter(Filter):
     """A filter that works on ICalendar files."""
 
+    content_type = 'text/calendar'
+
     def __init__(self, default_timezone):
         self.tzify = lambda dt: as_tz_aware_ts(dt, default_timezone)
         self.children = []
@@ -703,8 +705,6 @@ class CalendarFilter(Filter):
         return ret
 
     def check(self, name, file):
-        if file.content_type != 'text/calendar':
-            return False
         c = file.calendar
         if c is None:
             return False
@@ -722,8 +722,14 @@ class CalendarFilter(Filter):
 
     def check_from_indexes(self, name, indexes):
         for child_filter in self.children:
-            if not child_filter.match_indexes(
-                    indexes, self.tzify):
+            try:
+                if not child_filter.match_indexes(
+                        indexes, self.tzify):
+                    return False
+            except MissingProperty as e:
+                logging.warning(
+                    'calendar_query: Ignoring calendar object %s, due '
+                    'to missing property %s', name, e.property_name)
                 return False
         return True
 
@@ -792,7 +798,7 @@ class ICalendarFile(File):
         else:
             for component in subcomponents:
                 try:
-                    return describe_component(component)
+                    return component["SUMMARY"]
                 except KeyError:
                     pass
         return super(ICalendarFile, self).describe(name)
